xkcd: Barrel - Part 1

- Archive
- What If?
- Blag
- Store
- About

A webcomic of romance,
sarcasm, math, and language.
XKCD updates every Monday, Wednesday, and Friday.
Barrel - Part 1

- |<
- < Prev
- Random
- Next >
- >|

- |<
- < Prev
- Random
- Next >
- >|

Permanent link to this comic: http://xkcd.com/1/
Image URL (for hotlinking/embedding): http://imgs.xkcd.com/comics/barrel_cropped_(1).jpg
[[A boy sits in a barrel which is floating in an ocean.]] Boy: I wonder where I'll float next? [[The barrel drifts into the distance. Nothing else can be seen.]] {{Alt: Don't we all.}}
Search comic titles and transcripts:
RSS Feed - Atom Feed
Comics I enjoy:
Three Word Phrase, Oglaf (nsfw), SMBC, Dinosaur Comics, A Softer World, Buttersafe, Perry Bible Fellowship, Questionable Content, Buttercup Festival

Warning: this comic occasionally contains strong language (which may be unsuitable for children), unusual humor (which may be unsuitable for adults), and advanced mathematics (which may be unsuitable for liberal-arts majors).

BTC 1NfBXWqseXc9rCBc3Cbbu6HjxYssFUgkH6
We did not invent the algorithm. The algorithm consistently finds Jesus. The algorithm killed Jeeves.
The algorithm is banned in China. The algorithm is from Jersey. The algorithm constantly finds Jesus.
This is not the algorithm. This is close.

This work is licensed under a Creative Commons Attribution-NonCommercial 2.5 License.

This means you're free to copy and share these comics (but not to sell them). More details.